Index: /usr/ports/Mk/bsd.port.mk
===================================================================
--- /usr/ports/Mk/bsd.port.mk	(revision 363531)
+++ /usr/ports/Mk/bsd.port.mk	(working copy)
@@ -1180,21 +1180,29 @@
 
 .else
 
-# Look for ${PATCH_WRKSRC}/.../*.orig files, and (re-)create
-# ${FILEDIR}/patch-* files from them.
+# Look for files named "*.orig" under ${PATCH_WRKSRC} and (re-)generate
+# ${FILEDIR}/patch-* files from them.  By default, '-' (dash, minus) is
+# used to replace path separators in patch file names; it can be set to
+# something else via PATCH_PATH_SEPARATOR variable (note that only [-+_]
+# characters are allowed).
 
 .if !target(makepatch)
+PATCH_PATH_SEPARATOR?=	-
 makepatch: ${FILESDIR}
+.if empty(PATCH_PATH_SEPARATOR) || ${PATCH_PATH_SEPARATOR:C/[-+_]//}
+	@${ECHO_MSG} "Error (${.TARGET}) PATCH_PATH_SEPARATOR must be one of the [-+_] characters."
+	@${FALSE}
+.endif
 	@(cd ${PATCH_WRKSRC}; \
 		for i in `find . -type f -name '*.orig'`; do \
-			ORG=$$i; \
-			NEW=$${i%.orig}; \
+			ORG=$${i#./}; \
+			NEW=$${ORG%.orig}; \
 			cmp -s $${ORG} $${NEW} && continue; \
-			OUT=${FILESDIR}`${ECHO} $${NEW} | \
-				${SED} -e 's|/|__|g' \
-					-e 's|^\.__|/patch-|'`; \
-			${ECHO} ${DIFF} -ud $${ORG} $${NEW} '>' $${OUT}; \
-			${DIFF} -ud $${ORG} $${NEW} > $${OUT} || ${TRUE}; \
+			OUT=${FILESDIR}/`${ECHO} $${NEW} | \
+				${SED} -e 's|/|${PATCH_PATH_SEPARATOR}|g' \
+					-e 's|^|patch-|'`; \
+			${ECHO} ${DIFF} -udp $${ORG} $${NEW} '>' $${OUT}; \
+			${DIFF} -udp $${ORG} $${NEW} > $${OUT} || ${TRUE}; \
 		done \
 	)
 .endif
